@@ -1,7 +1,7 @@
 # Human friendly input/output in Python.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: February 10, 2020
+# Last Change: February 16, 2020
 # URL: https://humanfriendly.readthedocs.io
 
 """The main module of the `humanfriendly` package."""
@@ -93,7 +93,7 @@ __all__ = (
 )
 
 # Semi-standard module versioning.
-__version__ = '6.1'
+__version__ = '7.0'
 
 # Spinners are redrawn at most this many seconds.
 minimum_spinner_interval = 0.2
@@ -130,7 +130,9 @@ length_size_units = (dict(prefix='nm', divider=1e-09, singular='nm', plural='nm'
                      dict(prefix='km', divider=1000, singular='km', plural='km'))
 
 # Common time units, used for formatting of time spans.
-time_units = (dict(divider=1e-3, singular='millisecond', plural='milliseconds', abbreviations=['ms']),
+time_units = (dict(divider=1e-9, singular='nanosecond', plural='nanoseconds', abbreviations=['ns']),
+              dict(divider=1e-6, singular='microsecond', plural='microseconds', abbreviations=['us']),
+              dict(divider=1e-3, singular='millisecond', plural='milliseconds', abbreviations=['ms']),
               dict(divider=1, singular='second', plural='seconds', abbreviations=['s', 'sec', 'secs']),
               dict(divider=60, singular='minute', plural='minutes', abbreviations=['m', 'min', 'mins']),
               dict(divider=60 * 60, singular='hour', plural='hours', abbreviations=['h']),
@@ -199,13 +201,9 @@ def coerce_seconds(value):
 
     When `value` is a :class:`datetime.timedelta` object the
     :func:`~datetime.timedelta.total_seconds()` method is called.
-    On Python 2.6 this method is not available so it is emulated.
     """
     if isinstance(value, datetime.timedelta):
-        if hasattr(value, 'total_seconds'):
-            return value.total_seconds()
-        else:
-            return (value.microseconds + (value.seconds + value.days * 24 * 3600) * 10**6) / 10**6
+        return value.total_seconds()
     if not isinstance(value, numbers.Number):
         msg = "Failed to coerce value to number of seconds! (%r)"
         raise ValueError(format(msg, value))
@@ -367,7 +365,7 @@ def parse_length(length):
     if tokens and isinstance(tokens[0], numbers.Number):
         # If the input contains only a number, it's assumed to be the number of metres.
         if len(tokens) == 1:
-            return int(tokens[0])
+            return tokens[0]
         # Otherwise we expect to find two tokens: A number and a unit.
         if len(tokens) == 2 and is_string(tokens[1]):
             normalized_unit = tokens[1].lower()
@@ -485,7 +483,7 @@ def format_timespan(num_seconds, detailed=False, max_units=3):
         # Slow path.
         result = []
         num_seconds = decimal.Decimal(str(num_seconds))
-        relevant_units = list(reversed(time_units[0 if detailed else 1:]))
+        relevant_units = list(reversed(time_units[0 if detailed else 3:]))
         for unit in relevant_units:
             # Extract the unit count from the remaining time.
             divider = decimal.Decimal(str(unit['divider']))
